#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Thu Nov  5 10:46:01 2020

Calculates the DIC outflow for the Amazon river using the gridded time series data files generated by osoda_calculate_gridded_predictions.py

@author: tom holding
"""

from os import path;
from string import Template;

from os_dic_outflow import calc_dic_outflow_from_transects;
from os_dic_outflow import process_dic_outflow_transects;

#carbonateParametersTemplate:  Template string (following string.Template formatting) for the carbonate chemistry gridded time series data. See global settings 'bestGriddedTimeSeriesPathTemplate' and 'longGriddedTimeSeriesPathTemplate' for examples
#outputDirectoryRoot:  Root directory of where to write output files to
#regions:  List of region names
#regionMaskPath:  netCDF file containing the region masks for each region. Mask variable names must match the region
#gridAreasPath:  precomputed grid cell areas. These are found in the aux_data folder. File path is defined in the global settings file.
#perimeterRadii:  set of perimeter radii to use (units: grid cells (1 degree))
#numSamples:  number of samples to use when calculating uncertainty
def main(carbonateParametersTemplate, outputDirectoryRoot, regions, regionMaskPath, gridAreasPath, perimeterRadii=range(1, 25), numSamples=100):
    outputDirectoryTemplate = Template(path.join(outputDirectoryRoot, "${REGION}"));
    ###run calculate_dic_outflow_from_circle_transects function in calc_dic_outflow_from_transects.py  
    calc_dic_outflow_from_transects.calculate_dic_outflow_from_circle_transects(carbonateParametersTemplate, outputDirectoryTemplate, regions, regionMaskPath, gridAreasPath, perimeterRadii, numSamples, verbose=True)
    
    ###run process_dic_outflow_transects.py
    inputDirectoryTemplate = outputDirectoryTemplate; #the input directory is the output directory from the previous step.
    process_dic_outflow_transects.process_dic_outflow_transects(inputDirectoryTemplate, regions, outputDirectoryRoot);
    